@@ -399,7 +399,7 @@ bool File__Duplicate_MpegTs::Parsing_Begin (const int8u* ToAdd, size_t ToAdd_Siz
 
     //Copying
     if (ToModify.Buffer!=NULL && ToModify.Size<FromTS.Size)
-        {delete ToModify.Buffer; ToModify.Buffer=NULL;}
+        {delete[] ToModify.Buffer; ToModify.Buffer=NULL;}
     if (ToModify.Buffer==NULL)
         ToModify.Buffer=new int8u[FromTS.Size+(FromTS.Size/188)*4];
     std::memcpy(ToModify.Buffer, FromTS.Buffer, FromTS.Begin+8); //Only up to last_section_number included
