@@ -60,6 +60,11 @@ enum generic
     Generic_Duration_String1,
     Generic_Duration_String2,
     Generic_Duration_String3,
+    Generic_Source_Duration,
+    Generic_Source_Duration_String,
+    Generic_Source_Duration_String1,
+    Generic_Source_Duration_String2,
+    Generic_Source_Duration_String3,
     Generic_BitRate_Mode,
     Generic_BitRate_Mode_String,
     Generic_BitRate,
@@ -70,7 +75,10 @@ enum generic
     Generic_BitRate_Nominal_String,
     Generic_BitRate_Maximum,
     Generic_BitRate_Maximum_String,
+    Generic_BitRate_Encoded,
+    Generic_BitRate_Encoded_String,
     Generic_FrameCount,
+    Generic_Source_FrameCount,
     Generic_ColorSpace,
     Generic_ChromaSubsampling,
     Generic_Resolution,
@@ -111,6 +119,30 @@ enum generic
     Generic_StreamSize_String4,
     Generic_StreamSize_String5,
     Generic_StreamSize_Proportion,
+    Generic_Source_StreamSize,
+    Generic_Source_StreamSize_String,
+    Generic_Source_StreamSize_String1,
+    Generic_Source_StreamSize_String2,
+    Generic_Source_StreamSize_String3,
+    Generic_Source_StreamSize_String4,
+    Generic_Source_StreamSize_String5,
+    Generic_Source_StreamSize_Proportion,
+    Generic_StreamSize_Encoded,
+    Generic_StreamSize_Encoded_String,
+    Generic_StreamSize_Encoded_String1,
+    Generic_StreamSize_Encoded_String2,
+    Generic_StreamSize_Encoded_String3,
+    Generic_StreamSize_Encoded_String4,
+    Generic_StreamSize_Encoded_String5,
+    Generic_StreamSize_Encoded_Proportion,
+    Generic_Source_StreamSize_Encoded,
+    Generic_Source_StreamSize_Encoded_String,
+    Generic_Source_StreamSize_Encoded_String1,
+    Generic_Source_StreamSize_Encoded_String2,
+    Generic_Source_StreamSize_Encoded_String3,
+    Generic_Source_StreamSize_Encoded_String4,
+    Generic_Source_StreamSize_Encoded_String5,
+    Generic_Source_StreamSize_Encoded_Proportion,
     Generic_Language,
     Generic_ServiceName,
     Generic_ServiceProvider,
@@ -495,6 +527,16 @@ enum video
     Video_Source_Duration_String1,
     Video_Source_Duration_String2,
     Video_Source_Duration_String3,
+    Video_Source_Duration_FirstFrame,
+    Video_Source_Duration_FirstFrame_String,
+    Video_Source_Duration_FirstFrame_String1,
+    Video_Source_Duration_FirstFrame_String2,
+    Video_Source_Duration_FirstFrame_String3,
+    Video_Source_Duration_LastFrame,
+    Video_Source_Duration_LastFrame_String,
+    Video_Source_Duration_LastFrame_String1,
+    Video_Source_Duration_LastFrame_String2,
+    Video_Source_Duration_LastFrame_String3,
     Video_BitRate_Mode,
     Video_BitRate_Mode_String,
     Video_BitRate,
@@ -505,6 +547,8 @@ enum video
     Video_BitRate_Nominal_String,
     Video_BitRate_Maximum,
     Video_BitRate_Maximum_String,
+    Video_BitRate_Encoded,
+    Video_BitRate_Encoded_String,
     Video_Width,
     Video_Width_String,
     Video_Width_Offset,
@@ -597,6 +641,22 @@ enum video
     Video_Source_StreamSize_String4,
     Video_Source_StreamSize_String5,
     Video_Source_StreamSize_Proportion,
+    Video_StreamSize_Encoded,
+    Video_StreamSize_Encoded_String,
+    Video_StreamSize_Encoded_String1,
+    Video_StreamSize_Encoded_String2,
+    Video_StreamSize_Encoded_String3,
+    Video_StreamSize_Encoded_String4,
+    Video_StreamSize_Encoded_String5,
+    Video_StreamSize_Encoded_Proportion,
+    Video_Source_StreamSize_Encoded,
+    Video_Source_StreamSize_Encoded_String,
+    Video_Source_StreamSize_Encoded_String1,
+    Video_Source_StreamSize_Encoded_String2,
+    Video_Source_StreamSize_Encoded_String3,
+    Video_Source_StreamSize_Encoded_String4,
+    Video_Source_StreamSize_Encoded_String5,
+    Video_Source_StreamSize_Encoded_Proportion,
     Video_Alignment,
     Video_Alignment_String,
     Video_Title,
@@ -731,6 +791,8 @@ enum audio
     Audio_BitRate_Nominal_String,
     Audio_BitRate_Maximum,
     Audio_BitRate_Maximum_String,
+    Audio_BitRate_Encoded,
+    Audio_BitRate_Encoded_String,
     Audio_Channel_s_,
     Audio_Channel_s__String,
     Audio_ChannelPositions,
@@ -739,6 +801,7 @@ enum audio
     Audio_SamplingRate,
     Audio_SamplingRate_String,
     Audio_SamplingCount,
+    Audio_Source_SamplingCount,
     Audio_FrameRate,
     Audio_FrameRate_String,
     Audio_FrameCount,
@@ -798,6 +861,22 @@ enum audio
     Audio_Source_StreamSize_String4,
     Audio_Source_StreamSize_String5,
     Audio_Source_StreamSize_Proportion,
+    Audio_StreamSize_Encoded,
+    Audio_StreamSize_Encoded_String,
+    Audio_StreamSize_Encoded_String1,
+    Audio_StreamSize_Encoded_String2,
+    Audio_StreamSize_Encoded_String3,
+    Audio_StreamSize_Encoded_String4,
+    Audio_StreamSize_Encoded_String5,
+    Audio_StreamSize_Encoded_Proportion,
+    Audio_Source_StreamSize_Encoded,
+    Audio_Source_StreamSize_Encoded_String,
+    Audio_Source_StreamSize_Encoded_String1,
+    Audio_Source_StreamSize_Encoded_String2,
+    Audio_Source_StreamSize_Encoded_String3,
+    Audio_Source_StreamSize_Encoded_String4,
+    Audio_Source_StreamSize_Encoded_String5,
+    Audio_Source_StreamSize_Encoded_Proportion,
     Audio_Alignment,
     Audio_Alignment_String,
     Audio_Interleave_VideoFrames,
@@ -876,11 +955,31 @@ enum text
     Text_Duration_String2,
     Text_Duration_String3,
     Text_Duration_String4,
+    Text_Duration_FirstFrame,
+    Text_Duration_FirstFrame_String,
+    Text_Duration_FirstFrame_String1,
+    Text_Duration_FirstFrame_String2,
+    Text_Duration_FirstFrame_String3,
+    Text_Duration_LastFrame,
+    Text_Duration_LastFrame_String,
+    Text_Duration_LastFrame_String1,
+    Text_Duration_LastFrame_String2,
+    Text_Duration_LastFrame_String3,
     Text_Source_Duration,
     Text_Source_Duration_String,
     Text_Source_Duration_String1,
     Text_Source_Duration_String2,
     Text_Source_Duration_String3,
+    Text_Source_Duration_FirstFrame,
+    Text_Source_Duration_FirstFrame_String,
+    Text_Source_Duration_FirstFrame_String1,
+    Text_Source_Duration_FirstFrame_String2,
+    Text_Source_Duration_FirstFrame_String3,
+    Text_Source_Duration_LastFrame,
+    Text_Source_Duration_LastFrame_String,
+    Text_Source_Duration_LastFrame_String1,
+    Text_Source_Duration_LastFrame_String2,
+    Text_Source_Duration_LastFrame_String3,
     Text_BitRate_Mode,
     Text_BitRate_Mode_String,
     Text_BitRate,
@@ -891,6 +990,8 @@ enum text
     Text_BitRate_Nominal_String,
     Text_BitRate_Maximum,
     Text_BitRate_Maximum_String,
+    Text_BitRate_Encoded,
+    Text_BitRate_Encoded_String,
     Text_Width,
     Text_Width_String,
     Text_Height,
@@ -963,6 +1064,22 @@ enum text
     Text_Source_StreamSize_String4,
     Text_Source_StreamSize_String5,
     Text_Source_StreamSize_Proportion,
+    Text_StreamSize_Encoded,
+    Text_StreamSize_Encoded_String,
+    Text_StreamSize_Encoded_String1,
+    Text_StreamSize_Encoded_String2,
+    Text_StreamSize_Encoded_String3,
+    Text_StreamSize_Encoded_String4,
+    Text_StreamSize_Encoded_String5,
+    Text_StreamSize_Encoded_Proportion,
+    Text_Source_StreamSize_Encoded,
+    Text_Source_StreamSize_Encoded_String,
+    Text_Source_StreamSize_Encoded_String1,
+    Text_Source_StreamSize_Encoded_String2,
+    Text_Source_StreamSize_Encoded_String3,
+    Text_Source_StreamSize_Encoded_String4,
+    Text_Source_StreamSize_Encoded_String5,
+    Text_Source_StreamSize_Encoded_Proportion,
     Text_Title,
     Text_Encoded_Library,
     Text_Encoded_Library_String,
