@@ -93,6 +93,7 @@ MediaInfo_Config_MediaInfo::MediaInfo_Config_MediaInfo()
     File_MpegTs_ForceMenu=false;
     File_MpegTs_stream_type_Trust=true;
     File_MpegTs_Atsc_transport_stream_id_Trust=true;
+    File_MpegTs_RealTime=false;
     File_Bdmv_ParseTargetedFile=true;
     #if defined(MEDIAINFO_DVDIF_YES)
     File_DvDif_DisableAudioIfIsInContainer=false;
@@ -101,6 +102,9 @@ MediaInfo_Config_MediaInfo::MediaInfo_Config_MediaInfo()
     #if defined(MEDIAINFO_DVDIF_ANALYZE_YES)
         File_DvDif_Analysis=false;
     #endif //defined(MEDIAINFO_DVDIF_ANALYZE_YES)
+    #if MEDIAINFO_MACROBLOCKS
+        File_Macroblocks_Parse=false;
+    #endif //MEDIAINFO_MACROBLOCKS
     File_GrowingFile_Delay=10;
     #if defined(MEDIAINFO_LIBMMS_YES)
         File_Mmsh_Describe_Only=false;
@@ -471,6 +475,15 @@ Ztring MediaInfo_Config_MediaInfo::Option (const String &Option, const String &V
             return _T("Event manager is disabled due to compilation options");
         #endif //MEDIAINFO_EVENTS
     }
+    else if (Option_Lower==_T("file_subfile_ids_set"))
+    {
+        #if MEDIAINFO_EVENTS
+            SubFile_IDs_Set(Value);
+            return Ztring();
+        #else //MEDIAINFO_EVENTS
+            return _T("Event manager is disabled due to compilation options");
+        #endif //MEDIAINFO_EVENTS
+    }
     else if (Option_Lower==_T("file_parseundecodableframes"))
     {
         #if MEDIAINFO_EVENTS
@@ -507,6 +520,15 @@ Ztring MediaInfo_Config_MediaInfo::Option (const String &Option, const String &V
     {
         return File_MpegTs_Atsc_transport_stream_id_Trust_Get()?"1":"0";
     }
+    else if (Option_Lower==_T("file_mpegts_realtime"))
+    {
+        File_MpegTs_RealTime_Set(!(Value==_T("0") || Value.empty()));
+        return _T("");
+    }
+    else if (Option_Lower==_T("file_mpegts_realtime_get"))
+    {
+        return File_MpegTs_RealTime_Get()?"1":"0";
+    }
     else if (Option_Lower==_T("file_bdmv_parsetargetedfile"))
     {
         File_Bdmv_ParseTargetedFile_Set(!(Value==_T("0") || Value.empty()));
@@ -567,6 +589,23 @@ Ztring MediaInfo_Config_MediaInfo::Option (const String &Option, const String &V
             return _T("DVDIF Analysis is disabled due to compilation options");
         #endif //defined(MEDIAINFO_DVDIF_ANALYZE_YES)
     }
+    else if (Option_Lower==_T("file_macroblocks_parse"))
+    {
+        #if MEDIAINFO_MACROBLOCKS
+            File_Macroblocks_Parse_Set(!(Value==_T("0") || Value.empty()));
+            return _T("");
+        #else //MEDIAINFO_MACROBLOCKS
+            return _T("Macroblock parsing is disabled due to compilation options");
+        #endif //MEDIAINFO_MACROBLOCKS
+    }
+    else if (Option_Lower==_T("file_macroblocks_parse_get"))
+    {
+        #if MEDIAINFO_MACROBLOCKS
+            return File_Macroblocks_Parse_Get()?"1":"0";
+        #else //MEDIAINFO_MACROBLOCKS
+            return _T("Macroblock parsing is disabled due to compilation options");
+        #endif //MEDIAINFO_MACROBLOCKS
+    }
     else if (Option_Lower==_T("file_growingfile_delay"))
     {
         File_GrowingFile_Delay_Set(Ztring(Value).To_float64());
@@ -1220,6 +1259,22 @@ int64u MediaInfo_Config_MediaInfo::SubFile_StreamID_Get ()
 
     return SubFile_StreamID;
 }
+
+//---------------------------------------------------------------------------
+void MediaInfo_Config_MediaInfo::SubFile_IDs_Set (Ztring Value)
+{
+    CriticalSectionLocker CSL(CS);
+
+    SubFile_IDs=Value;
+}
+
+//---------------------------------------------------------------------------
+Ztring MediaInfo_Config_MediaInfo::SubFile_IDs_Get ()
+{
+    CriticalSectionLocker CSL(CS);
+
+    return SubFile_IDs;
+}
 #endif //MEDIAINFO_EVENTS
 
 //***************************************************************************
@@ -1276,6 +1331,8 @@ Ztring MediaInfo_Config_MediaInfo::Event_CallBackFunction_Set (const Ztring &Val
         {
             if (List[Pos].find(_T("CallBack=memory://"))==0)
                 Event_CallBackFunction=(MediaInfo_Event_CallBackFunction*)Ztring(List[Pos].substr(18, std::string::npos)).To_int64u();
+            else if (List[Pos].find(_T("UserHandle=memory://"))==0)
+                Event_UserHandler=(void*)Ztring(List[Pos].substr(20, std::string::npos)).To_int64u();
             else if (List[Pos].find(_T("UserHandler=memory://"))==0)
                 Event_UserHandler=(void*)Ztring(List[Pos].substr(21, std::string::npos)).To_int64u();
             else
@@ -1409,6 +1466,21 @@ bool MediaInfo_Config_MediaInfo::File_MpegTs_Atsc_transport_stream_id_Trust_Get
     return Temp;
 }
 
+//---------------------------------------------------------------------------
+void MediaInfo_Config_MediaInfo::File_MpegTs_RealTime_Set (bool NewValue)
+{
+    CriticalSectionLocker CSL(CS);
+    File_MpegTs_RealTime=NewValue;
+}
+
+bool MediaInfo_Config_MediaInfo::File_MpegTs_RealTime_Get ()
+{
+    CS.Enter();
+    bool Temp=File_MpegTs_RealTime;
+    CS.Leave();
+    return Temp;
+}
+
 //---------------------------------------------------------------------------
 void MediaInfo_Config_MediaInfo::File_Bdmv_ParseTargetedFile_Set (bool NewValue)
 {
@@ -1471,6 +1543,22 @@ bool MediaInfo_Config_MediaInfo::File_DvDif_Analysis_Get ()
 }
 #endif //defined(MEDIAINFO_DVDIF_ANALYZE_YES)
 
+//---------------------------------------------------------------------------
+#if MEDIAINFO_MACROBLOCKS
+void MediaInfo_Config_MediaInfo::File_Macroblocks_Parse_Set (bool NewValue)
+{
+    CriticalSectionLocker CSL(CS);
+    File_Macroblocks_Parse=NewValue;
+}
+
+bool MediaInfo_Config_MediaInfo::File_Macroblocks_Parse_Get ()
+{
+    CriticalSectionLocker CSL(CS);
+    bool Temp=File_Macroblocks_Parse;
+    return Temp;
+}
+#endif //MEDIAINFO_MACROBLOCKS
+
 //---------------------------------------------------------------------------
 void MediaInfo_Config_MediaInfo::File_GrowingFile_Delay_Set (float64 NewValue)
 {
