@@ -377,23 +377,40 @@ void MediaInfo_Internal::Entry()
     Config.State_Set(0);
     CS.Leave();
 
-        if (0);
-    #if defined(MEDIAINFO_LIBCURL_YES)
-        else if ((Config.File_Names[0].size()>=7
-          && Config.File_Names[0][0]==_T('h')
-          && Config.File_Names[0][1]==_T('t')
-          && Config.File_Names[0][2]==_T('t')
-          && Config.File_Names[0][3]==_T('p')
-          && Config.File_Names[0][4]==_T(':')
-          && Config.File_Names[0][5]==_T('/')
-          && Config.File_Names[0][6]==_T('/'))
-         || (Config.File_Names[0].size()>=6
-          && Config.File_Names[0][0]==_T('f')
-          && Config.File_Names[0][1]==_T('t')
-          && Config.File_Names[0][2]==_T('p')
-          && Config.File_Names[0][3]==_T(':')
-          && Config.File_Names[0][4]==_T('/')
-          && Config.File_Names[0][5]==_T('/')))
+    if ((Config.File_Names[0].size()>=6
+        && Config.File_Names[0][0]==_T('m')
+        && Config.File_Names[0][1]==_T('m')
+        && Config.File_Names[0][2]==_T('s')
+        && Config.File_Names[0][3]==_T(':')
+        && Config.File_Names[0][4]==_T('/')
+        && Config.File_Names[0][5]==_T('/'))
+        || (Config.File_Names[0].size()>=7
+        && Config.File_Names[0][0]==_T('m')
+        && Config.File_Names[0][1]==_T('m')
+        && Config.File_Names[0][2]==_T('s')
+        && Config.File_Names[0][3]==_T('h')
+        && Config.File_Names[0][4]==_T(':')
+        && Config.File_Names[0][5]==_T('/')
+        && Config.File_Names[0][6]==_T('/')))
+        #if defined(MEDIAINFO_LIBMMS_YES)
+            Reader_libmms().Format_Test(this, Config.File_Names[0]);
+        #else //MEDIAINFO_LIBMMS_YES
+            {
+            #if MEDIAINFO_EVENTS
+                struct MediaInfo_Event_Log_0 Event;
+                Event.EventCode=MediaInfo_EventCode_Create(MediaInfo_Parser_None, MediaInfo_Event_Log, 0);
+                Event.Type=0xC0;
+                Event.Severity=0xFF;
+                Event.MessageCode=0;
+                Event.MessageStringU=L"Libmms cupport is disabled due to compilation options";
+                Event.MessageStringA="Libmms cupport is disabled due to compilation options";
+                MediaInfoLib::Config.Event_Send((const int8u*)&Event, sizeof(MediaInfo_Event_Log_0));
+            #endif //MEDIAINFO_EVENTS
+            }
+        #endif //MEDIAINFO_LIBMMS_YES
+
+    else if (Config.File_Names[0].find(_T("://"))!=string::npos)
+        #if defined(MEDIAINFO_LIBCURL_YES)
         {
             CS.Enter();
             if (Reader)
@@ -411,26 +428,20 @@ void MediaInfo_Internal::Entry()
                     return;
             #endif //MEDIAINFO_NEXTPACKET
         }
-    #endif //MEDIAINFO_LIBCURL_YES
-
-    #if defined(MEDIAINFO_LIBMMS_YES)
-        else if ((Config.File_Names[0].size()>=6
-          && Config.File_Names[0][0]==_T('m')
-          && Config.File_Names[0][1]==_T('m')
-          && Config.File_Names[0][2]==_T('s')
-          && Config.File_Names[0][3]==_T(':')
-          && Config.File_Names[0][4]==_T('/')
-          && Config.File_Names[0][5]==_T('/'))
-         || (Config.File_Names[0].size()>=7
-          && Config.File_Names[0][0]==_T('m')
-          && Config.File_Names[0][1]==_T('m')
-          && Config.File_Names[0][2]==_T('s')
-          && Config.File_Names[0][3]==_T('h')
-          && Config.File_Names[0][4]==_T(':')
-          && Config.File_Names[0][5]==_T('/')
-          && Config.File_Names[0][6]==_T('/')))
-            Reader_libmms().Format_Test(this, Config.File_Names[0]);
-    #endif //MEDIAINFO_LIBMMS_YES
+        #else //MEDIAINFO_LIBCURL_YES
+            {
+            #if MEDIAINFO_EVENTS
+                struct MediaInfo_Event_Log_0 Event;
+                Event.EventCode=MediaInfo_EventCode_Create(MediaInfo_Parser_None, MediaInfo_Event_Log, 0);
+                Event.Type=0xC0;
+                Event.Severity=0xFF;
+                Event.MessageCode=0;
+                Event.MessageStringU=L"Libcurl support is disabled due to compilation options";
+                Event.MessageStringA="Libcurl support is disabled due to compilation options";
+                MediaInfoLib::Config.Event_Send((const int8u*)&Event, sizeof(MediaInfo_Event_Log_0));
+            #endif //MEDIAINFO_EVENTS
+            }
+        #endif //MEDIAINFO_LIBCURL_YES
 
     #if defined(MEDIAINFO_DIRECTORY_YES)
         else if (Dir::Exists(Config.File_Names[0]))
@@ -464,10 +475,15 @@ void MediaInfo_Internal::Entry()
 }
 
 //---------------------------------------------------------------------------
-size_t MediaInfo_Internal::Open (const int8u* Begin, size_t Begin_Size, const int8u*, size_t, int64u File_Size)
+size_t MediaInfo_Internal::Open (const int8u* Begin, size_t Begin_Size, const int8u* End, size_t End_Size, int64u File_Size)
 {
     Open_Buffer_Init(File_Size);
     Open_Buffer_Continue(Begin, Begin_Size);
+    if (End && Begin_Size+End_Size<=File_Size)
+    {
+        Open_Buffer_Init(File_Size, File_Size-End_Size);
+        Open_Buffer_Continue(End, End_Size);
+    }
     Open_Buffer_Finalize();
 
     return 1;
@@ -697,22 +713,6 @@ std::bitset<32> MediaInfo_Internal::Open_NextPacket ()
     std::bitset<32> ToReturn=Info==NULL?std::bitset<32>(0x0F):Info->Status;
     if (Demux_EventWasSent)
         ToReturn[8]=true; //bit 8 is for the reception of a frame
-    
-    #if MEDIAINFO_DEMUX
-        //Multiple images
-        if (!Demux_EventWasSent && Config.File_Names_Pos<Config.File_Names.size())
-        {
-            delete Reader; Reader=new Reader_File();
-            CS.Leave();
-            Reader->Format_Test(this, Config.File_Names[Config.File_Names_Pos]);
-            CS.Enter();
-            Info->Frame_Count_NotParsedIncluded=Config.File_Names_Pos;
-            Config.File_Names_Pos++;
-            Info->Status.reset(File__Analyze::IsFinished);
-            ToReturn.reset(File__Analyze::IsFinished);
-            return Open_NextPacket();
-        }
-    #endif //MEDIAINFO_DEMUX
 
     return ToReturn;
 }
