@@ -399,11 +399,17 @@ void File_Gxf::Streams_Finish_PerStream(size_t StreamID, stream &Temp)
                         int64u TimeCode_First=((File_Gxf_TimeCode*)Streams[TimeCode->first].Parser)->TimeCode_First;
                         if (TimeCode_First==(int64u)-1)
                             TimeCode_First=TimeCode->second;
-                        Fill(Stream_Video, StreamPos_Last, Video_Delay, TimeCode_First, 0);
-                        Fill(Stream_Video, StreamPos_Last, Video_Delay_Source, "Container");
+                        if (TimeCode_First!=(int64u)-1)
+                        {
+                            Fill(Stream_Video, StreamPos_Last, Video_Delay, TimeCode_First, 0);
+                            Fill(Stream_Video, StreamPos_Last, Video_Delay_Source, "Container");
+                        }
                     }
 
                 Merge(*Temp.Parser, Stream_Video, 0, StreamPos_Last);
+                
+                Fill(Stream_Video, StreamPos_Last, Video_ID, StreamID, 10, true);
+                Fill(Stream_Video, StreamPos_Last, "Title", Temp.MediaName);
 
                 //Special cases
                 if (Temp.Parser->Count_Get(Stream_Text))
@@ -449,6 +455,22 @@ void File_Gxf::Streams_Finish_PerStream(size_t StreamID, stream &Temp)
                     }
 
                 Merge(*Temp.Parser, Stream_Audio, Pos, StreamPos_Last, false);
+
+                Ztring ID=Ztring::ToZtring(StreamID);
+                if (Temp.IsChannelGrouping)
+                    ID+=_T(" / ")+Ztring::ToZtring(StreamID+1); //Second half of the channel grouping
+                Ztring ID_String=ID;
+                if (!Retrieve(Stream_Audio, StreamPos_Last, Audio_ID).empty())
+                {
+                    ID+=_T('-')+Retrieve(Stream_Audio, StreamPos_Last, Audio_ID);
+                    ID_String+=_T('-')+Retrieve(Stream_Audio, StreamPos_Last, Audio_ID_String);
+                }
+                Fill(Stream_Audio, StreamPos_Last, Audio_ID, ID, true);
+                Fill(Stream_Audio, StreamPos_Last, Audio_ID_String, ID_String, true);
+                Fill(Stream_Audio, StreamPos_Last, "Title", Temp.MediaName);
+                if (Temp.IsChannelGrouping)
+                    Fill(StreamKind_Last, StreamPos_Last, "Title", Streams[StreamID+1].MediaName); //Second half of the channel grouping
+
                 for (std::map<std::string, Ztring>::iterator Info=Temp.Infos.begin(); Info!=Temp.Infos.end(); Info++)
                     if (Retrieve(Stream_Audio, StreamPos_Last, Info->first.c_str()).empty())
                         Fill(Stream_Audio, StreamPos_Last, Info->first.c_str(), Info->second);
@@ -476,19 +498,6 @@ void File_Gxf::Streams_Finish_PerStream(size_t StreamID, stream &Temp)
                 StreamPos_Last=(size_t)-1;
             }
         }
-
-        //Metadata
-        if (StreamKind_Last!=Stream_Max)
-        {
-            Fill(StreamKind_Last, StreamPos_Last, General_ID, StreamID, 10, true);
-            Fill(StreamKind_Last, StreamPos_Last, "Title", Temp.MediaName);
-            if (Temp.IsChannelGrouping)
-            {
-                //Second half of the channel grouping
-                Fill(StreamKind_Last, StreamPos_Last, "Title", Streams[StreamID+1].MediaName);
-                Fill(StreamKind_Last, StreamPos_Last, General_ID, StreamID+1, 10);
-            }
-        }
     }
 }
 
@@ -752,7 +761,7 @@ void File_Gxf::map()
 
     //Parsing
     int8u Version;
-    Element_Begin("Preamble");
+    Element_Begin1("Preamble");
         BS_Begin();
         Mark_1();
         Mark_1();
@@ -760,9 +769,9 @@ void File_Gxf::map()
         Get_S1(5, Version,                                      "Version");
         BS_End();
         Skip_B1(                                                "Reserved");
-    Element_End();
+    Element_End0();
 
-    Element_Begin("Material Data");
+    Element_Begin1("Material Data");
         int16u SectionLength;
         Get_B2 (SectionLength,                                  "Section Length");
         if (Element_Offset+SectionLength>=Element_Size)
@@ -770,7 +779,7 @@ void File_Gxf::map()
         int64u Material_Data_End=Element_Offset+SectionLength;
         while (Element_Offset<Material_Data_End)
         {
-            Element_Begin("Tag");
+            Element_Begin1("Tag");
             int8u Tag, DataLength;
             Get_B1(Tag,                                         "Tag");
             Get_B1(DataLength,                                  "Data Length");
@@ -859,11 +868,11 @@ void File_Gxf::map()
                             break;
                 default   : Skip_XX(DataLength,                 "Unknown");
             }
-            Element_End();
+            Element_End0();
         }
-    Element_End();
+    Element_End0();
 
-    Element_Begin("Track Description");
+    Element_Begin1("Track Description");
         int32u Stream_Video_FrameRate_Code=(int32u)-1, Stream_Video_FieldsPerFrame_Code=(int32u)-1;
         Get_B2 (SectionLength,                                  "Section Length");
         if (Element_Offset+SectionLength>=Element_Size)
@@ -871,17 +880,17 @@ void File_Gxf::map()
         int64u Track_Data_End=Element_Offset+SectionLength;
         while (Element_Offset<Track_Data_End)
         {
-            Element_Begin("Track");
+            Element_Begin1("Track");
             int16u TrackLength;
             int8u  MediaType, TrackID;
-            Get_B1 (MediaType,                                  "Media type"); Param_Info(Gxf_MediaTypes(MediaType&0x7F));
+            Get_B1 (MediaType,                                  "Media type"); Param_Info1(Gxf_MediaTypes(MediaType&0x7F));
             Get_B1 (TrackID,                                    "Track ID");
             Get_B2 (TrackLength,                                "Track Length");
             if (Element_Offset+TrackLength>=Track_Data_End)
                 TrackLength=(int16u)(Track_Data_End-Element_Offset);
             int64u Track_End=Element_Offset+TrackLength;
-            Element_Info(TrackID&0x3F);
-            Element_Info(Gxf_MediaTypes(MediaType&0x7F));
+            Element_Info1(TrackID&0x3F);
+            Element_Info1(Gxf_MediaTypes(MediaType&0x7F));
 
             FILLING_BEGIN();
                 MediaType&=0x7F; //Remove the last bit
@@ -1037,13 +1046,13 @@ void File_Gxf::map()
                 }
             FILLING_END();
 
-            int8u Hours=(int8u)-1, Minutes=(int8u)-1, Seconds=(int8u)-1, Frames=(int8u)-1;
+            int8u Hours=(int8u)-1, Minutes=(int8u)-1, Seconds=(int8u)-1, Fields=(int8u)-1;
             bool  Invalid=true, DropFrame=true;
             bool  TimeCode_Parsed=false;
 
             while (Element_Offset<Track_End)
             {
-                Element_Begin("Tag");
+                Element_Begin1("Tag");
                 int8u Tag, DataLength;
                 Get_B1(Tag,                                     "Tag");
                 Get_B1(DataLength,                              "Data Length");
@@ -1071,7 +1080,7 @@ void File_Gxf::map()
                                     else if (MediaType==7 || MediaType==8 || MediaType==24)
                                     {
                                         //TimeCode
-                                        Get_B1 (Frames,         "Frame");
+                                        Get_B1 (Fields,         "Fields");
                                         Get_B1 (Seconds,        "Second");
                                         Get_B1 (Minutes,        "Minute");
                                         BS_Begin();
@@ -1105,7 +1114,7 @@ void File_Gxf::map()
                     case 0x50 : //Frame rate
                                 if (DataLength==4)
                                 {
-                                    Get_B4 (Streams[TrackID].FrameRate_Code, "Content"); Param_Info(Gxf_FrameRate(Streams[TrackID].FrameRate_Code)); Element_Info(Gxf_FrameRate(Streams[TrackID].FrameRate_Code));
+                                    Get_B4 (Streams[TrackID].FrameRate_Code, "Content"); Param_Info1(Gxf_FrameRate(Streams[TrackID].FrameRate_Code)); Element_Info1(Gxf_FrameRate(Streams[TrackID].FrameRate_Code));
                                     for (std::map<int8u, int64u>::iterator TimeCode=TimeCodes.begin(); TimeCode!=TimeCodes.end(); TimeCode++)
                                         if (TrackID==TimeCode->first)
                                             ((File_Gxf_TimeCode*)Streams[TrackID].Parser)->FrameRate_Code=Streams[0x00].FrameRate_Code;
@@ -1118,7 +1127,7 @@ void File_Gxf::map()
                     case 0x51 : //Lines per frame
                                 if (DataLength==4)
                                 {
-                                    Get_B4 (Streams[TrackID].LinesPerFrame_Code, "Content"); Param_Info(Gxf_LinesPerFrame_Height(Streams[TrackID].LinesPerFrame_Code)); Element_Info(Gxf_LinesPerFrame_Height(Streams[TrackID].LinesPerFrame_Code));
+                                    Get_B4 (Streams[TrackID].LinesPerFrame_Code, "Content"); Param_Info1(Gxf_LinesPerFrame_Height(Streams[TrackID].LinesPerFrame_Code)); Element_Info1(Gxf_LinesPerFrame_Height(Streams[TrackID].LinesPerFrame_Code));
                                 }
                                 else
                                     Skip_XX(DataLength,         "Unknown");
@@ -1126,7 +1135,7 @@ void File_Gxf::map()
                     case 0x52 : //Fields per frame
                                 if (DataLength==4)
                                 {
-                                    Get_B4 (Streams[TrackID].FieldsPerFrame_Code, "Content"); Param_Info(Gxf_FieldsPerFrame(Streams[TrackID].FieldsPerFrame_Code)); Element_Info(Gxf_FieldsPerFrame(Streams[TrackID].FieldsPerFrame_Code));
+                                    Get_B4 (Streams[TrackID].FieldsPerFrame_Code, "Content"); Param_Info1(Gxf_FieldsPerFrame(Streams[TrackID].FieldsPerFrame_Code)); Element_Info1(Gxf_FieldsPerFrame(Streams[TrackID].FieldsPerFrame_Code));
                                     if (Gxf_MediaTypes_StreamKind(MediaType)==Stream_Video)
                                     {
                                         Stream_Video_FieldsPerFrame_Code=Streams[TrackID].FieldsPerFrame_Code;
@@ -1141,9 +1150,9 @@ void File_Gxf::map()
                                 break;
                     default   : Skip_XX(DataLength,             "Unknown");
                 }
-                Element_End();
+                Element_End0();
             }
-            Element_End();
+            Element_End0();
 
             //Test on TimeCode
             if (TimeCode_Parsed && !Invalid)
@@ -1155,11 +1164,11 @@ void File_Gxf::map()
                     TimeCodes[TrackID]=Hours  *60*60*1000
                                       +Minutes   *60*1000
                                       +Seconds      *1000
-                                      +float64_int64s(Frames*1000/FrameRate);
+                                      +float64_int64s(Fields*1000/(FrameRate*2));
                 }
             }
         }
-    Element_End();
+    Element_End0();
     if (Element_Offset<Element_Size)
         Skip_XX(Element_Size-Element_Offset,                    "Padding");
 
@@ -1194,7 +1203,7 @@ void File_Gxf::media()
     //Parsing
     int32u  MediaFieldNumber;
     int8u   MediaType;
-    Element_Begin("Preamble");
+    Element_Begin1("Preamble");
         Get_B1 (MediaType,                                      "Media type");
         Get_B1 (TrackNumber,                                    "Track number");
         Get_B4 (MediaFieldNumber,                               "Media field number");
@@ -1206,8 +1215,8 @@ void File_Gxf::media()
         Skip_B1(                                                "Flags");
         Skip_B1(                                                "Reserved");
         TrackNumber&=0x3F;
-    Element_End();
-    Element_Info(TrackNumber);
+    Element_End0();
+    Element_Info1(TrackNumber);
 
     //Managing audio 32768-sample DTS synchro
     if (Gxf_MediaTypes_StreamKind(MediaType)==Stream_Audio && MediaFieldNumber==Material_Fields_First && Gxf_FrameRate(Streams[TrackNumber].FrameRate_Code) && Streams[TrackNumber].FirstFrameDuration)
@@ -1245,7 +1254,8 @@ void File_Gxf::media()
                     if (TimeCode_First==(int64u)-1)
                         TimeCode_First=TimeCodes.begin()->second;
                 }
-                TimeCode_First*=1000000;
+                if (TimeCode_First!=(int64u)-1)
+                    TimeCode_First*=1000000;
                 if (Gxf_MediaTypes_StreamKind(Streams[TrackNumber].MediaType)==Stream_Video)
                 {
                     if (Gxf_FrameRate(Streams[TrackNumber].FrameRate_Code))
@@ -1372,10 +1382,10 @@ void File_Gxf::UMF_file()
 
     //Parsing
     int32u PayloadDataLength;
-    Element_Begin("Preamble");
+    Element_Begin1("Preamble");
         Skip_B1(                                                "First/last packet flag");
         Get_B4 (PayloadDataLength,                              "Payload data length");
-    Element_End();
+    Element_End0();
 
     if (UMF_File==NULL)
     {
@@ -1441,6 +1451,7 @@ File__Analyze* File_Gxf::ChooseParser_ChannelGrouping(int8u TrackID)
     Parser->Channel_Total=2;
     Parser->Endianness='L';
     Parser->ByteDepth=3;
+    Parser->IsAes3=true;
 
     #if MEDIAINFO_DEMUX
         if (Demux_UnpacketizeContainer)
