@@ -131,49 +131,46 @@ void File_Cdp::Streams_Accept()
 //---------------------------------------------------------------------------
 void File_Cdp::Streams_Update()
 {
+    Clear(Stream_Text);
+
     //Per stream
     for (size_t Pos=0; Pos<Streams.size(); Pos++)
-        if (Streams[Pos] && Streams[Pos]->Parser && Streams[Pos]->Parser->Status[IsFilled] && Streams[Pos]->Parser->Status[IsUpdated])
+        if (Streams[Pos] && Streams[Pos]->Parser && Streams[Pos]->Parser->Status[IsFilled] /*&& Streams[Pos]->Parser->Status[IsUpdated]*/ && Streams[Pos]->Parser->Count_Get(Stream_Text))
             Streams_Update_PerStream(Pos);
 }
 
 //---------------------------------------------------------------------------
 void File_Cdp::Streams_Update_PerStream(size_t Pos)
 {
+    if (Streams[Pos]==NULL)
+        return;
+
     Update(Streams[Pos]->Parser);
 
-    //Creating the text stream if not already present
-    if (Streams[Pos]->StreamPos==(size_t)-1)
-    {
-        Streams[Pos]->StreamPos=0;
-        for (size_t Pos2=0; Pos2<Streams.size(); Pos2++)
+    if (Streams[Pos]->Parser)
+        for (size_t Pos2=0; Pos2<Streams[Pos]->Parser->Count_Get(Stream_Text); Pos2++)
         {
-            if (Pos2==Pos)
-            {
-                Stream_Prepare(Stream_Text, Streams[Pos]->StreamPos);
-                if (WithAppleHeader)
-                    Fill(Stream_Text, StreamPos_Last, "MuxingMode", "Final Cut");
-                Fill(Stream_Text, StreamPos_Last, "MuxingMode", "CDP");
-            }
-            else if (Pos2<Pos && Streams[Pos2] && Streams[Pos2]->StreamPos!=(size_t)-1 && Streams[Pos2]->StreamPos>=Streams[Pos]->StreamPos)
-                Streams[Pos]->StreamPos=Streams[Pos2]->StreamPos+1;
-            else if (Streams[Pos2] && Streams[Pos2]->StreamPos!=(size_t)-1)
-                Streams[Pos2]->StreamPos++;
+            Stream_Prepare(Stream_Text);
+            Merge(*Streams[Pos]->Parser, Stream_Text, Pos2, StreamPos_Last);
+            if (WithAppleHeader)
+                Fill(Stream_Text, StreamPos_Last, "MuxingMode", "Final Cut");
+            Fill(Stream_Text, StreamPos_Last, "MuxingMode", "CDP");
+            Fill(Stream_Text, StreamPos_Last, Text_ID, Streams[Pos]->Parser->Retrieve(Stream_Text, Pos2, Text_ID), true);
         }
-    }
-
-    Merge(*Streams[Pos]->Parser, Stream_Text, 0, Streams[Pos]->StreamPos);
-    if (Pos<2)
-        Fill(Stream_Text, Streams[Pos]->StreamPos, Text_ID, _T("608-")+Ztring::ToZtring(Pos+1), true);
 }
 
 //---------------------------------------------------------------------------
 void File_Cdp::Streams_Finish()
 {
+    Clear(Stream_Text);
+
     //Per stream
     for (size_t Pos=0; Pos<Streams.size(); Pos++)
-        if (Streams[Pos] && Streams[Pos]->Parser && Streams[Pos]->Parser->Status[IsFilled] && Streams[Pos]->Parser->Status[IsUpdated])
+        if (Streams[Pos] && Streams[Pos]->Parser && Streams[Pos]->Parser->Status[IsAccepted] /*&& Streams[Pos]->Parser->Status[IsUpdated]*/)
+        {
             Finish(Streams[Pos]->Parser);
+            Streams_Update_PerStream(Pos);
+        }
 }
 
 //***************************************************************************
@@ -214,6 +211,16 @@ void File_Cdp::Read_Buffer_Continue()
         FILLING_END();
     }
 
+    //CRC
+    int8u CRC=0;
+    for (size_t Pos=WithAppleHeader?8:0; Pos<Buffer_Size; Pos++)
+        CRC+=Buffer[Pos];
+    if (CRC)
+    {
+        Skip_XX(Element_Size-Element_Offset,                    "Invalid data (CRC fails)");
+        return;
+    }
+
     cdp_header();
     while(Element_Offset<Element_Size)
     {
@@ -241,13 +248,13 @@ void File_Cdp::Read_Buffer_Continue()
 //---------------------------------------------------------------------------
 void File_Cdp::cdp_header()
 {
-    Element_Begin("cdp_header");
+    Element_Begin1("cdp_header");
     int16u cdp_identifier;
     int8u cdp_frame_rate;
     Get_B2 (   cdp_identifier,                                  "cdp_identifier");
     Skip_B1(                                                    "cdp_length");
     BS_Begin();
-    Get_S1 (4, cdp_frame_rate,                                  "cdp_frame_rate"); Param_Info(Ztring::ToZtring(Cdp_cdp_frame_rate(cdp_frame_rate))+_T(" fps"));
+    Get_S1 (4, cdp_frame_rate,                                  "cdp_frame_rate"); Param_Info1(Ztring::ToZtring(Cdp_cdp_frame_rate(cdp_frame_rate))+_T(" fps"));
     Skip_S1(4,                                                  "Reserved");
     Skip_SB(                                                    "time_code_present");
     Skip_SB(                                                    "ccdata_present");
@@ -259,7 +266,7 @@ void File_Cdp::cdp_header()
     Skip_SB(                                                    "Reserved");
     BS_End();
     Skip_B2(                                                    "cdp_hdr_sequence_cntr");
-    Element_End();
+    Element_End0();
 
     FILLING_BEGIN();
         if (!Status[IsAccepted])
@@ -278,7 +285,7 @@ void File_Cdp::cdp_header()
 //---------------------------------------------------------------------------
 void File_Cdp::time_code_section()
 {
-    Element_Begin("time_code_section");
+    Element_Begin1("time_code_section");
     Skip_B1(                                                    "time_code_section_id");
     BS_Begin();
     Mark_1();
@@ -296,7 +303,7 @@ void File_Cdp::time_code_section()
     Skip_S1(2,                                                  "tc_10fr");
     Skip_S1(4,                                                  "tc_1fr");
     BS_End();
-    Element_End();
+    Element_End0();
 }
 
 //---------------------------------------------------------------------------
@@ -304,7 +311,7 @@ void File_Cdp::ccdata_section()
 {
     //Parsing
     int8u cc_count;
-    Element_Begin("ccdata_section");
+    Element_Begin1("ccdata_section");
     Skip_B1(                                                    "ccdata_id");
     BS_Begin();
     Mark_1();
@@ -314,7 +321,7 @@ void File_Cdp::ccdata_section()
     BS_End();
     for (int8u Pos=0; Pos<cc_count; Pos++)
     {
-        Element_Begin("cc");
+        Element_Begin1("cc");
         int8u cc_type;
         bool  cc_valid;
         BS_Begin();
@@ -324,11 +331,11 @@ void File_Cdp::ccdata_section()
         Mark_1();
         Mark_1();
         Get_SB (   cc_valid,                                    "cc_valid");
-        Get_S1 (2, cc_type,                                     "cc_type"); Param_Info(Cdp_cc_type(cc_type));
+        Get_S1 (2, cc_type,                                     "cc_type"); Param_Info1(Cdp_cc_type(cc_type));
         BS_End();
         if (cc_valid)
         {
-            Element_Begin("cc_data");
+            Element_Begin1("cc_data");
                 //Calculating the parser position
                 int8u Parser_Pos=cc_type==3?2:cc_type; //cc_type 2 and 3 are for the same text
 
@@ -344,6 +351,7 @@ void File_Cdp::ccdata_section()
                     {
                         #if defined(MEDIAINFO_EIA608_YES)
                             Streams[Parser_Pos]->Parser=new File_Eia608();
+                            ((File_Eia608*)Streams[Parser_Pos]->Parser)->cc_type=cc_type;
                         #else //defined(MEDIAINFO_EIA608_YES)
                             Streams[Parser_Pos]->Parser=new File__Analyze();
                         #endif //defined(MEDIAINFO_EIA608_YES)
@@ -371,7 +379,8 @@ void File_Cdp::ccdata_section()
                     {
                         #if defined(MEDIAINFO_EIA708_YES)
                             ((File_Eia708*)Streams[2]->Parser)->cc_type=cc_type;
-                            ((File_Eia708*)Streams[2]->Parser)->AspectRatio=AspectRatio;
+                            if (AspectRatio)
+                                ((File_Eia708*)Streams[2]->Parser)->AspectRatio=AspectRatio;
                         #endif //defined(MEDIAINFO_EIA708_YES)
                     }
                     else
@@ -393,13 +402,18 @@ void File_Cdp::ccdata_section()
                 }
                 else
                     Skip_XX(2,                                  "Data");
-            Element_End();
+            Element_End0();
         }
         else
             Skip_XX(2,                                          "Junk");
-        Element_End();
+        Element_End0();
     }
-    Element_End();
+    Element_End0();
+
+    Frame_Count++;
+    Frame_Count_InThisBlock++;
+    if (Frame_Count_NotParsedIncluded!=(int64u)-1)
+        Frame_Count_NotParsedIncluded++;
 }
 
 //---------------------------------------------------------------------------
@@ -407,7 +421,7 @@ void File_Cdp::ccsvcinfo_section()
 {
     //Parsing
     int8u svc_count;
-    Element_Begin("ccsvcinfo_section");
+    Element_Begin1("ccsvcinfo_section");
     Skip_B1(                                                    "ccsvcinfo_id");
     BS_Begin();
     Skip_SB(                                                    "reserved");
@@ -418,7 +432,7 @@ void File_Cdp::ccsvcinfo_section()
     BS_End();
     for (int8u Pos=0; Pos<svc_count; Pos++)
     {
-        Element_Begin("svc");
+        Element_Begin1("svc");
         bool  csn_size;
         BS_Begin();
         Skip_SB(                                                "reserved");
@@ -433,7 +447,7 @@ void File_Cdp::ccsvcinfo_section()
         BS_End();
 
         //svc_data_byte - caption_service_descriptor
-        Element_Begin("service");
+        Element_Begin1("service");
         Ztring language;
         bool digital_cc;
         Get_Local(3, language,                                  "language");
@@ -451,20 +465,20 @@ void File_Cdp::ccsvcinfo_section()
         Skip_SB(                                                "wide_aspect_ratio");
         Skip_S2(14,                                             "reserved");
         BS_End();
-        Element_End();
-        Element_End();
+        Element_End0();
+        Element_End0();
     }
-    Element_End();
+    Element_End0();
 }
 
 //---------------------------------------------------------------------------
 void File_Cdp::cdp_footer()
 {
-    Element_Begin("cdp_footer");
+    Element_Begin1("cdp_footer");
     Skip_B1(                                                    "cdp_footer_id");
     Skip_B2(                                                    "cdp_ftr_sequence_cntr");
     Skip_B1(                                                    "packet_checksum");
-    Element_End();
+    Element_End0();
 }
 
 //---------------------------------------------------------------------------
@@ -472,11 +486,11 @@ void File_Cdp::future_section()
 {
     //Parsing
     int8u length;
-    Element_Begin("future_section");
+    Element_Begin1("future_section");
     Skip_B1(                                                    "future_section_id");
     Get_B1 (length,                                             "length");
     Skip_XX(length,                                             "Unknown");
-    Element_End();
+    Element_End0();
 }
 
 //***************************************************************************
